@@ -23,10 +23,15 @@
 
 
 QString Constants::CSV_SEPARATOR = ";";
+
+#ifndef Q_WS_MAEMO_5
 QString Constants::WORK_DIR = QDir::home().absolutePath() + "/.stultitiaSimplex";
+#else
+QString Constants::WORK_DIR = QDir::home().absolutePath() + "/MyDocs/stultitiaSimplex";
+#endif
 QString Constants::SOUNDLIST_FILE = WORK_DIR + "/buttons.csv";
 QString Constants::SOUNDS_DIR = WORK_DIR + "/sounds";
-QString Constants::VERSION = "1.0.1";
+QString Constants::VERSION = "1.0.2";
 
 Constants::Constants()
 {
